function [pdfout,grid] = burialage(data, muontype, sample, sigma, binres, consts, makeplot, plotbanana)

%This function determines the burial age that best fits concentrations of
%Be-10 and Al-26 given a simple surface buildup and burial history. Muon
%production based on Lifton et al. 2013 (LSD scaling scheme)is included
%both during the buildup period and the burial period.
%
%Burial age and error is determined using a systematic parameter search
%and chi-squared statistic to create a continuous probability density
%function. Additionally, and mostly for comparison or in cases of samples
%near saturation, the mean-value age is also calculated using the FMINLBFGS
%optimization algorithm (obtained from the Matlab file exchange).
%
%Note: inputing a multi-line data file will plot all data on one burial
%plot, but only the 'sample' you select will be analyzed numerically. See
%'burial_ages.m' to analyze multiple burial ages at once.
%
%
%INPUTS:
%data = name of ascii file with nine columns of data (e.g. 'data.txt'):
%   column 1 is the depth of burial for each sample; (cm)
%   column 2 is the average density of material above each sample; (g/cc)
%   column 3 is the decimal latitude of each sample (used in buildup model
%   for production)
%   column 4 is the dicmal longitude of each sample (used in buildup model
%   for production)
%   column 5 is the elevation of each sample site; (m)
%   column 6 is measured [10Be]; (atoms/g)
%   column 7 is the 1 sigma error in [10Be]; (atoms/g)
%   column 8 is measured [26Al]; (atoms/g)
%   column 9 is the 1 sigma error in [26Al]; (atoms/g)
%
%muontype = deep muon scheme to use; surface buildup model uses Lifton et
%al. (2013), but this  parameter refers to the scheme used at depth. If =
%0, there is no deep muon production; if = 1 Lifton (2013) is used at depth
%(estimate from J. Stone, pers. comm.); if = 2 Heisinger (2002) is used at
%depth.
%
%sigma = specifies the sigma confidence for the error ellipse
%
%sample = the row number of the sample you wish to plot; all samples will
%plot regardless, however, because of muons, the plot is structurally
%different at different depths and will therefore only be accurate for the
%sample specified here unless 1) all sample depths are identical or 2) muon
%production is not included (muontype = 0)
%
%binres = the bin resolution used to calculate pdf (note: increasing this
%constant geometrically increases calculation time. A value of around 2000
%is usually sufficient, which generates a pdf curve using 2000 points over
%the age range
%
%consts = a matlab structure containing constants used in the LSD scaling
%model. This structure is loaded in the startup.m file.
%
%makeplot = if true, will output individual plots for each sample. It is
%useful to suppress this if goal is to just creat pdfs for age.
%
%plotbananna = if true, will also plot the banana window
%
%
%OUTPUT:
%
%Running this program also writes a .mat file to your working directory.
%The name format is the name of your data input file plus the sample depth,
%where the depth is taken from the first element in the data input file.
%This file contains a data structure called "burialoutput" with the
%following results of the age calculation: depthID (sample depth, used to
%ID your output), pdfmaxage (the most probable age as determined from the
%probability density function), sigma1plus and sigma1minus (the +/- 1sigma
%errors in pdfmaxage), sigma2plus and sigma2minus (the +/- 2sigma errors in
%pdfmaxage), burial_sim and pdf (matrices containing vectors for
%incremental time and probability--basically to allow reconstruction of the
%pdf), exposure_meanvalue (mean value of pre-buildup exposure age taken
%from FMINLBFGS optimization algorithm), burial_meanvalue (mean value of
%burial age taken from FMINLBFGS optimization algorithm), fval (residual of
%the minimization algorithm--should be 10^-5 or lower)
%
%note: edit lines 160-166 to manually change the build-up production rate to 
%some specified value. The default is to calculate the buildup production
%rates from surface production rates at the sample site.
%
%A. Hidy
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%load data

burial_data = load(data);

depths = burial_data(:,1);
densities = burial_data(:,2);
lats = burial_data(:,3);
longs = burial_data(:,4);
elevs = burial_data(:,5);
Be_concs = burial_data(:,6);
Be_errs = burial_data(:,7);
Al_concs = burial_data(:,8);
Al_errs = burial_data(:,9);
ratios = Al_concs./Be_concs;

%decay constants (1/s)

Be10_lambda = log(2)/1387000;
Al26_lambda = log(2)/720000;


%neutron attenuation length (g/cm^2)

neutron_atten = 160; %Follows Balco et al. (2008); see Gosse and Phillips (2001)

%spallogenic production (atoms/g/a)

refspalprod = 4.48; %Value from Balco et al. (2008); 4.96/1.106 to reflect recalibration of Nishiizumi et al. (2007)
ratio_init = 6.75; %Follows Balco et al. (2008); 6.1/1.106 to reflect recalibration of Nishiizumi et al. (2007)


%Get LSD scaling factors

maxage = 2000000; %age over which to integrate production rates

LSD10 = LSD(lats(sample),longs(sample),elevs(sample),1,maxage,-1,10);
LSD26 = LSD(lats(sample),longs(sample),elevs(sample),1,maxage,-1,26);


agegrid = 0:1:maxage;

%average spallogenic surface production rate over age range

Be10_spalsurf = mean(refspalprod.*interpolate(LSD10.tv,LSD10.Be,agegrid));
Al26_spalsurf = mean(refspalprod.*ratio_init.*interpolate(LSD26.tv,LSD26.Al,agegrid));


%average total muogenic surface production rate over age range

meanRC = mean(interpolate(LSD10.tv,LSD10.Rc,agegrid));
meanSPhi = mean(interpolate(LSD10.tv,LSD10.SPhi,agegrid));

Be10_musurf = P_mu_totalLSD(0,LSD10.pressure,meanRC,meanSPhi,consts,10,'no');
Al26_musurf = P_mu_totalLSD(0,LSD10.pressure,meanRC,meanSPhi,consts,26,'no');





%muonic production at depth

if muontype == 0 %no muon production
    Be10_mudepth = 0;
    Al26_mudepth = 0;
else if muontype == 1 %Use LSD rates based on
        Be10_mudepth = P_mu_totalLSD(depths(sample)*densities(sample),LSD10.pressure,meanRC,meanSPhi,consts,10,'no');
        Al26_mudepth = P_mu_totalLSD(depths(sample)*densities(sample),LSD10.pressure,meanRC,meanSPhi,consts,26,'no');
    else if muontype == 2
            Be10_mudepth = muonproduction_heisinger(depths(sample)*densities(sample),elevs,1);
            Al26_mudepth = muonproduction_heisinger(depths(sample)*densities(sample),elevs,0);
        end
    end
end

%override buildup production rates here (for example, to assume basin-wide
%production rate for source)

Be10_spalbuildup = Be10_spalsurf;
Al26_spalbuildup = Al26_spalsurf;
Be10_mubuildup = Be10_musurf;
Al26_mubuildup = Al26_musurf;


%rock density used during buildup phase (g/cc)

r_density = 2.65;


%simple buildup model with no erosion

%buildup due to exposure at surface; assumes no inheritance

    function Be10_conc_buildup = Be10_buildup(t_exposure)
        Be10spall_buildup = (Be10_spalbuildup/Be10_lambda)*(1-exp(-Be10_lambda*t_exposure));
        Be10muon_buildup = (Be10_mubuildup/Be10_lambda)*(1-exp(-Be10_lambda*t_exposure));
        Be10_conc_buildup = Be10spall_buildup + Be10muon_buildup;
    end

    function Al26_conc_buildup = Al26_buildup(t_exposure)
        Al26spall_buildup = (Al26_spalbuildup/Al26_lambda)*(1-exp(-Al26_lambda*t_exposure));
        Al26muon_buildup = (Al26_mubuildup/Al26_lambda)*(1-exp(-Al26_lambda*t_exposure));
        Al26_conc_buildup = Al26spall_buildup + Al26muon_buildup;
    end

%burial production; assume buildup is inheritance

    function Be10_conc_burial = Be10_burial(t_exposure, t_burial)
        Be10spall_burial = (Be10_spalsurf/Be10_lambda)*exp(-depths(sample)*densities(sample)/neutron_atten)*(1-exp(-Be10_lambda*t_burial));
        Be10muon_burial = (Be10_mudepth/Be10_lambda)*(1-exp(-Be10_lambda*t_burial));
        Be10inheritance = Be10_buildup(t_exposure)*exp(-Be10_lambda*t_burial);
        Be10_conc_burial = Be10spall_burial + Be10muon_burial + Be10inheritance;
    end

    function Al26_conc_burial = Al26_burial(t_exposure, t_burial)
        Al26spall_burial = (Al26_spalsurf/Al26_lambda)*exp(-depths(sample)*densities(sample)/neutron_atten)*(1-exp(-Al26_lambda*t_burial));
        Al26muon_burial = (Al26_mudepth/Al26_lambda)*(1-exp(-Al26_lambda*t_burial));
        Al26inheritance = Al26_buildup(t_exposure)*exp(-Al26_lambda*t_burial);
        Al26_conc_burial = Al26spall_burial + Al26muon_burial + Al26inheritance;
    end

%simple buildup model with erosion

%new lambda term spallation

    function Be10lambda = Be10_elambda(erate)
        
        Be10lambda = Be10_lambda + erate*r_density/neutron_atten;
    end

    function Al26lambda = Al26_elambda(erate)
        
        Al26lambda = Al26_lambda + erate*r_density/neutron_atten;
    end

%need effective lambda for muons; dominated by spall, so use rough
%estimate of 1500 (this value doesn't matter much since it only is used
%for plotting the banana

effective_muon_atten = 1500;

    function Be10lambdamu = Be10_elambdamu(erate)
        
        Be10lambdamu = Be10_lambda + erate*r_density/effective_muon_atten;
    end

    function Al26lambdamu = Al26_elambdamu(erate)
        
        Al26lambdamu = Al26_lambda + erate*r_density/effective_muon_atten;
    end

%buildup due to exposure at surface; assumes no inheritance

    function eBe10_conc_buildup = eBe10_buildup(t_exposure, erate)
        Be10spall_buildup = (Be10_spalbuildup./Be10_elambda(erate)).*(1-exp(-Be10_elambda(erate).*t_exposure));
        Be10muon_buildup = (Be10_mubuildup./Be10_elambdamu(erate)).*(1-exp(-Be10_elambdamu(erate).*t_exposure));
        eBe10_conc_buildup = Be10spall_buildup + Be10muon_buildup;
    end

    function eAl26_conc_buildup = eAl26_buildup(t_exposure, erate)
        Al26spall_buildup = (Al26_spalbuildup./Al26_elambda(erate)).*(1-exp(-Al26_elambda(erate).*t_exposure));
        Al26muon_buildup = (Al26_mubuildup./Al26_elambdamu(erate)).*(1-exp(-Al26_elambdamu(erate).*t_exposure));
        eAl26_conc_buildup = Al26spall_buildup + Al26muon_buildup;
    end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Generate probability density function

%pdf grid resulution

pdfres = binres;

%create burial and exposure grids
burial_sim = linspace(0,16000000,pdfres);
exposure_sim = logspace(0,7.2,pdfres);

%initialize matrices
Be10_matrix = zeros(numel(exposure_sim),numel(burial_sim));
Al26_matrix = zeros(numel(exposure_sim),numel(burial_sim));

for i = 1:numel(exposure_sim)
    for j = 1:numel(burial_sim)
        Be10_matrix(i,j) = Be10_burial(exposure_sim(i),burial_sim(j)); %burial ages in columns, exposure ages in rows
        Al26_matrix(i,j) = Al26_burial(exposure_sim(i),burial_sim(j)); %burial ages in columns, exposure ages in rows
    end
end

%use grid values to compute modeled results at each point and compare with
%measured concentrations to generate chi-squared grid

chi2be_matrix = abs((((Be10_matrix - Be_concs(sample))./Be_errs(sample))).^2);
chi2al_matrix = abs((((Al26_matrix - Al_concs(sample))./Al_errs(sample))).^2);
chi2total_matrix = chi2be_matrix + chi2al_matrix;

%convert chi-squared to probability using liklihood function
prob2total_matrix = exp(-chi2total_matrix./2);

%burial_av = sum(prob2total_matrix,1)./numel(burial_sim);
%sum(burial_av)

burial_max = max(prob2total_matrix);

%construct pdf normalized so area under curve=1
pdf = burial_max./sum(burial_max);
cdf = cumsum(pdf);
[b,i] = unique(cdf);



burialoutput.depthID = depths(sample);
burialoutput.pdfmaxage = burial_sim(pdf == max(pdf)); %burial age in Ma
burialoutput.sigma1plus = interp1(b,burial_sim(i),0.84135) - burialoutput.pdfmaxage; %del burial age in Ma
burialoutput.sigma1minus = burialoutput.pdfmaxage - interp1(b,burial_sim(i),0.15865); %del burial age in Ma
burialoutput.sigma2plus = interp1(b,burial_sim(i),0.977)- burialoutput.pdfmaxage; %del burial age in Ma
burialoutput.sigma2minus = burialoutput.pdfmaxage - interp1(b,burial_sim(i),0.023); %del burial age in Ma
burialoutput.burial_sim = burial_sim;
burialoutput.pdf = pdf;





%Gnerate mean-value solution using FMINLBFGS algorithm


    function optage = mean_value(x)
        optage = abs(Al26_burial(x(1),x(2)) - Al_concs(sample)) + abs(Be10_burial(x(1),x(2)) - Be_concs(sample));
    end


%parameters for optimization algorithm

n = 200; %grid size
grid_burs = logspace(0,7.1,n); %burial age range
grid_exps = logspace(0,7.1,n); %exposure age range

options = struct('GoalsExactAchieve',0, 'MaxIter', 500, 'MaxFunEvals', 1000);


%calculation of best fit using grid approach

counter = 0;
loopcounter = 0;
while counter < 1
    kexp = randi(numel(grid_burs),1);
    kbur = randi(numel(grid_burs),1);
    [X, fval] = fminlbfgs(@mean_value,[grid_exps(kexp), grid_burs(kbur)], options);
    
    if loopcounter >= 400
        break;
        %for cases where mean value plots in forbidden zone, this method
        %will fail to minimize; loopcounter limits the number of runs
        %before abandoning minimization
        
    end
    
    if fval >= 1
        loopcounter = loopcounter + 1;
        continue
    else
        counter = counter + 1;
    end
    
    burialoutput.exposure_meanvalue = X(1)/1e3; %exposure in ka
    burialoutput.burial_meanvalue = X(2)/1e6; %burial in Ma
    burialoutput.fval = fval; %deviation
end


%view output in workspace
burialoutput

pdfout = pdf;
grid = burial_sim;

%write output file to workspace
name = strcat(data,mat2str(depths(sample)));
save(name,'burialoutput');


%Plotting parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%pdf plot

pdf_axis = [0 1.5*(burialoutput.pdfmaxage + burialoutput.sigma2plus)/10^6 0 1.2*max(pdf)];

error2_high = (burialoutput.pdfmaxage + burialoutput.sigma2plus)/10^6;
error2_low = (burialoutput.pdfmaxage - burialoutput.sigma2minus)/10^6;
error1_high = (burialoutput.pdfmaxage + burialoutput.sigma1plus)/10^6;
error1_low = (burialoutput.pdfmaxage - burialoutput.sigma1minus)/10^6;



figure
hold on
box on
axis(pdf_axis)
xlabel('Burial Age (Ma)');
ylabel('normalized probability');
title(strcat({'PDF: sample '},{name}));

plot(burial_sim./(10^6),pdf,'b-', 'linewidth', 2)

line([error2_high error2_high], [0 1], 'linestyle','-.', 'color', 'k')
line([error2_low error2_low], [0 1], 'linestyle','-.', 'color', 'k')
line([error1_high error1_high], [0 1], 'linestyle','-.', 'color', 'r')
line([error1_low error1_low], [0 1], 'linestyle','-.', 'color', 'r')

%supress all burial plots?
if nargin < 7
    return
end

%burial plot

%define axis for plot
plot_axis = [3 7.5 0 8]; %x-axis, y-axis

%Define locations of contours on burial plot, in years
n1 = [250000 500000 1000000 2000000 3000000 4000000 8000000]; %burial contours
n2 = [1000 10000 100000 1000000]; %exposure contours

%erosion rate contours for erosion banana, cm/a
n3 = [200 50 10  2  0.5 0.1  0.0100]/1000;


%Create grids for plot contours
texp = 1:100:20000000;
tbur = 1:100:20000000;
eeros = 0:0.001/1000:500/1000;


figure
hold on
box on
axis(plot_axis);
xlabel('log[^{10}Be] (atoms g^{-1})');
ylabel('^{26}Al/^{10}Be');
title(strcat({'Burial Plot: sample '},{name}));

%Plot error ellipses and mean values for sample concentrations
plot(log10(Be_concs(sample)),ratios(sample),'k.');

ellipse(Be_concs(sample),Be_errs(sample),Al_concs(sample),Al_errs(sample),sigma);


%burial contours
for k = 1:numel(n1)
    plot(log10(Be10_burial(texp,n1(k))),Al26_burial(texp,n1(k))./Be10_burial(texp,n1(k)),'b:');
end


%exposure contours
for k = 1:numel(n2)
    plot(log10(Be10_burial(n2(k),tbur)),Al26_burial(n2(k),tbur)./Be10_burial(n2(k),tbur),'k--');
end


%surface curve for zero erosion
plot(log10(Be10_burial(texp,0)),Al26_burial(texp,0)./Be10_burial(texp,0),'r-','linewidth',2);


%burial path starting at zero-erosion surface saturation (lower plot
%boundary)
plot(log10(Be10_burial(100000000,tbur)),Al26_burial(100000000,tbur)./Be10_burial(100000000,tbur),'k-','linewidth',2);


%include erosion banana?
if nargin < 8
    return
end

plot(log10(eBe10_buildup(10000000,eeros)), eAl26_buildup(10000000,eeros)./eBe10_buildup(10000000,eeros),'g-','linewidth',2);
plot(log10(Be10_burial(texp,0)),Al26_burial(texp,0)./Be10_burial(texp,0),'r-','linewidth',2);
for k = 1:numel(n3)
    plot(log10(eBe10_buildup(texp,n3(k))), eAl26_buildup(texp,n3(k))./eBe10_buildup(texp,n3(k)),'g-');
    plot(log10(Be10_burial(texp,0)),Al26_burial(texp,0)./Be10_burial(texp,0),'r-','linewidth',2);
end



%depth curve for zero erosion

    function Be10_conc_buildupA = Be10_buildupA(t_exposure)
        Be10spall_buildup = (Be10_spalsurf/Be10_lambda)*(1-exp(-Be10_lambda*t_exposure))*exp(-depths(sample)*densities(sample)/160);
        Be10muon_buildup = (Be10_mudepth/Be10_lambda)*(1-exp(-Be10_lambda*t_exposure));
        Be10_conc_buildupA = Be10spall_buildup + Be10muon_buildup;
    end

    function Al26_conc_buildupA = Al26_buildupA(t_exposure)
        Al26spall_buildup = (Al26_spalsurf/Al26_lambda)*(1-exp(-Al26_lambda*t_exposure))*exp(-depths(sample)*densities(sample)/160);
        Al26muon_buildup = (Al26_mudepth/Al26_lambda)*(1-exp(-Al26_lambda*t_exposure));
        Al26_conc_buildupA = Al26spall_buildup + Al26muon_buildup;
    end

plot(log10(Be10_buildupA(texp)),Al26_buildupA(texp)./Be10_buildupA(texp),'r-','linewidth',2);

end
